<?xml version="1.0"?>
<!-- 
  Purpose:
     Contains all parameters for (X)HTML
     (Sorted against the list in "Part 1. HTML Parameter Reference" in
      the DocBook XSL Stylesheets User Reference, see link below)
     
   See Also:
     * http://docbook.sourceforge.net/release/xsl/current/doc/html/index.html

   Author(s):    Thomas Schraitle <toms@opensuse.org>
   Copyright: 2012, Thomas Schraitle

-->

<xsl:stylesheet version="1.0"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns="http://www.w3.org/1999/xhtml">


<!-- 1. Admonitions  ============================================ -->
  <!-- Use graphics in admonitions?  0=no, 1=yes -->
  <xsl:param name="admon.graphics" select="1"/>
  <!-- Path to admonition graphics -->
  <xsl:param name="admon.graphics.path">static/images/</xsl:param>
  <!-- Specifies the CSS style attribute that should be added to admonitions -->
  <xsl:param name="admon.style" select="''"/>


<!-- 2. Callouts ================================================ -->
  <xsl:param name="callout.graphics.path">static/images/</xsl:param>
  <xsl:param name="callout.graphics" select="0"/>

<!-- 3. EBNF ==================================================== -->

<!-- 4. ToC/LoT/Index Generation ================================ -->
  <xsl:param name="toc.section.depth" select="1"/>
  <xsl:param name="generate.toc">
appendix  toc,title
article/appendix  nop
article   toc,title
book      toc,title,figure,table,example,equation
chapter   toc,title
part      toc,title
preface   toc,title
qandaset  toc
reference toc,title
sect1     toc
sect2     toc
sect3     toc
sect4     toc
sect5     toc
section   toc
set       toc,title
</xsl:param>
  
  
<!-- 5. Stylesheet Extensions =================================== -->

<!-- 6. Automatic labeling ====================================== -->
  <xsl:param name="section.autolabel" select="1"/>
  <xsl:param name="section.label.includes.component.label" select="1"/>

<!-- 7. HTML ==================================================== -->
  <xsl:param name="css.decoration" select="0"/>
  <xsl:param name="draft.watermark.image">static/images/draft_html.png</xsl:param>
  <xsl:param name="docbook.css.link" select="0"/>
  <xsl:param name="html.stylesheet">static/css/susebooks.css</xsl:param>
  <xsl:param name="make.clean.html" select="1"/>
  <xsl:param name="make.valid.html" select="1"/>

<!-- 8. XSLT Processing ========================================= -->
  <!-- Rule over footers? -->
  <xsl:param name="footer.rule" select="0"/>

<!-- 9. Meta/*Info and Titlepages =============================== -->
  <xsl:param name="generate.legalnotice.link" select="0"/>
  
<!-- 10. Reference Pages ======================================== -->

<!-- 11. Tables ================================================= -->

<!-- 12. QAndASet =============================================== -->
<xsl:param name="qanda.defaultlabel">none</xsl:param>
<xsl:param name="qandadiv.autolabel" select="0"></xsl:param>

<!-- 13. Linking ================================================ -->

<!-- 14. Cross References ======================================= -->

<!-- 15. Lists ================================================== -->

<!-- 16. Bibliography =========================================== -->

<!-- 17. Glossary =============================================== -->

<!-- 18. Miscellaneous ========================================== -->
  <xsl:param name="menuchoice.separator" select="$daps.breadcrumbs.sep"/>
  <xsl:param name="formal.title.placement">
figure after
example before
equation before
table before
procedure before
task before
  </xsl:param>
  
  <!-- From the DocBook XHMTL stylesheet's "formal.xsl" -->
  <xsl:param name="formal.object.break.after">0</xsl:param>
  
<!-- 19. Annotations ============================================ -->

<!-- 20. Graphics =============================================== -->
  <xsl:param name="img.src.path">images/</xsl:param><!-- DB XSL Version >=1.67.1 -->
  <xsl:param name="make.graphic.viewport" select="0"/> <!-- Do not create tables around graphics. -->
  
<!-- 21. Chunking =============================================== -->
  <!-- The base directory of chunks -->
  <xsl:param name="base.dir">./html/</xsl:param>
  
  <xsl:param name="chunk.fast" select="1"/>
  <!-- Depth to which sections should be chunked -->
  <xsl:param name="chunk.section.depth" select="0"/>
  <!-- Use ID value of chunk elements as the filename? -->
  <xsl:param name="use.id.as.filename" select="1"/>
  
  <!-- Use graphics in navigational headers and footers? -->
  <xsl:param name="navig.graphics" select="1"/>
  <!-- Path to navigational graphics -->
  <xsl:param name="navig.graphics.path">navig/</xsl:param>
  <!-- Extension for navigational graphics -->
  <xsl:param name="navig.graphics.extension" select="'.png'"/>
  <!-- Identifies the name of the root HTML file when chunking -->
  <xsl:param name="root.filename">index</xsl:param>


<!-- 27. Localization =========================================== -->
  <!-- Use customized language files -->
  <xsl:param name="local.l10n.xml" select="document('../common/l10n/l10n.xml')"/>

<!-- 28. SUSE specific parameters =============================== -->
  <!--  -->
  <xsl:param name="admon.graphics.prefix">icon-</xsl:param>
  
  <xsl:param name="daps.header.logo">static/images/logo.png</xsl:param>
  <xsl:param name="daps.header.logo.alt">SUSE</xsl:param>
  <xsl:param name="daps.header.js.library">static/js/jquery-1.4.2.min.js</xsl:param>
  <xsl:param name="daps.header.js.custom">static/js/susebooks.js</xsl:param>
  
  <!-- Create breadcrumbs navigation?  -->
  <xsl:param name="generate.breadcrumbs" select="1"/>
  <xsl:param name="breadcrumbs.prev">&#9664;<!--&#9668;--></xsl:param>
  <xsl:param name="breadcrumbs.next">&#9654;<!--&#9658;--></xsl:param>

  <!--  Bubble TOC options -->
  <xsl:param name="rootelementname">
    <xsl:choose>
      <xsl:when test="local-name(key('id', $rootid)) != ''">
        <xsl:value-of select="local-name(key('id', $rootid))"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="local-name(/*)"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:param>
  
  <xsl:param name="bubbletoc.section.depth">2</xsl:param>
  <xsl:param name="bubbletoc.max.depth">2</xsl:param>

  <xsl:param name="bubbletoc.max.depth.shallow">
    <xsl:choose>
      <xsl:when test="$rootelementname = 'article'">
        <xsl:value-of select="1"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="0"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:param>
  
  <!-- Separator for chapter and book name in the XHTML output -->
  <xsl:param name="head.content.title.separator"> | </xsl:param>
  
  <!-- Create version information before title? -->
  <xsl:param name="generate.version.info" select="1"/>
  
  <!-- Create the language and format areas in the header? -->
  <xsl:param name="generate.pickers" select="0"/>
  
  <!-- Create sharing links for Facebook, Google+, Twitter? -->
  <xsl:param name="generate.sharelinks" select="1"/>
  
  <!-- Separator between separate links: -->
  <xsl:param name="daps.breadcrumbs.sep">&#xa0;›&#xa0;</xsl:param>
  
  <!--  Create permalinks?-->
  <xsl:param name="generate.permalinks" select="1"/>
  
  <!-- Should information from SVN properties be used? yes=1|no=0 -->
  <xsl:param name="use.meta" select="0"/>

  <!-- Show arrows before and after a paragraph that applies only to a certain
       architecture? -->
  <xsl:param name="para.use.arch" select="1"/>
  
</xsl:stylesheet>
